import React from 'react';
import { View, StyleSheet } from 'react-native';
import { useReaderRef, useSettingsObserver, useLocationObserver } from './hooks';
export const ReadiumView = _ref => {
  let {
    file,
    settings,
    location,
    onLocationChange,
    onTableOfContents
  } = _ref;
  const readerRef = useReaderRef({
    file,
    onLocationChange,
    onTableOfContents
  });
  const reader = readerRef.current;
  useSettingsObserver(reader, settings);
  useLocationObserver(reader, location);
  return /*#__PURE__*/React.createElement(View, {
    style: styles.container
  }, !reader && /*#__PURE__*/React.createElement("div", {
    style: styles.loader
  }, "Loading reader..."), /*#__PURE__*/React.createElement("div", {
    id: "D2Reader-Container",
    style: styles.d2Container
  }, reader && /*#__PURE__*/React.createElement("button", {
    onClick: reader.previousPage,
    style: styles.button
  }, "\u2039"), /*#__PURE__*/React.createElement("main", {
    style: styles.maximize,
    tabIndex: -1,
    id: "iframe-wrapper"
  }, /*#__PURE__*/React.createElement("div", {
    id: "reader-loading",
    className: "loading",
    style: styles.loader
  }), /*#__PURE__*/React.createElement("div", {
    id: "reader-error",
    className: "error"
  })), reader && /*#__PURE__*/React.createElement("button", {
    onClick: reader.nextPage,
    style: styles.button
  }, "\u203A")));
};
const styles = StyleSheet.create({
  container: {
    width: '100%',
    height: '100%'
  },
  d2Container: {
    width: '100%',
    height: '100%',
    display: 'flex'
  },
  maximize: {
    width: 'calc(100% - 100px)',
    height: '100%',
    display: 'flex'
  },
  button: {
    width: 50,
    fontSize: 100,
    backgroundColor: 'transparent',
    border: 'none'
  },
  loader: {
    width: '100%',
    height: '100%',
    textAlign: 'center',
    position: 'relative',
    top: 'calc(50% - 10px)'
  }
});
//# sourceMappingURL=ReadiumView.js.map